cream-core
This crate contains the core types and traits for the cream crate.
Macros
- Declare a resource type with a given name and id.
- Declare a schema with a given name and id.
- Load a JSON file from the
include_str!macro.
Structs
- A single attribute of a SCIM schema.
- Wrapper around
time::OffsetDateTimewhich serializes according to RFC3339. - Metadata about a resource.
- A reference to a resource or external URL.
- A resource type.
- A SCIM schema
- An extension schema for a resource type.
Enums
- The mutability of an attribute.
- When an attribute is returned.
- The data type of an attribute.
- The uniqueness of an attribute.